@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2015-2024 Alexey Rochev
+// SPDX-FileCopyrightText: 2015-2025 Alexey Rochev
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -8,13 +8,14 @@
 #include "iconthemesetup.h"
 
 #include "fileutils.h"
-#include "literals.h"
 #include "startup/recoloringsvgiconengineplugin.h"
 
+using namespace Qt::StringLiterals;
+
 namespace tremotesf {
     void setupIconTheme() {
-        QIcon::setThemeSearchPaths({resolveExternalBundledResourcesPath("icons"_l1)});
-        QIcon::setThemeName(TREMOTESF_BUNDLED_ICON_THEME ""_l1);
+        QIcon::setThemeSearchPaths({resolveExternalBundledResourcesPath("icons"_L1)});
+        QIcon::setThemeName(TREMOTESF_BUNDLED_ICON_THEME ""_L1);
         QApplication::setStyle(new RecoloringSvgIconStyle(qApp));
     }
 }
