@@ -1,12 +1,13 @@
-// SPDX-FileCopyrightText: 2016 The Qt Company Ltd.
-//
-// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LGPL-3.0-only
 
 #ifndef TREMOTESF_RECOLORINGSVGICONENGINE_H
 #define TREMOTESF_RECOLORINGSVGICONENGINE_H
 
-#include <QIconEngine>
-#include <QSharedData>
+#include <QtGui/qiconengine.h>
+#include <QtCore/qshareddata.h>
+
+// clang-format off
 
 namespace tremotesf {
 
@@ -25,18 +26,19 @@ public:
                      QIcon::State state) override;
     QPixmap pixmap(const QSize &size, QIcon::Mode mode,
                    QIcon::State state) override;
+    QPixmap scaledPixmap(const QSize &size, QIcon::Mode mode,
+                         QIcon::State state, qreal scale) override;
 
     void addPixmap(const QPixmap &pixmap, QIcon::Mode mode,
                    QIcon::State state) override;
     void addFile(const QString &fileName, const QSize &size,
                  QIcon::Mode mode, QIcon::State state) override;
 
+    bool isNull() override;
     QString key() const override;
     QIconEngine *clone() const override;
     bool read(QDataStream &in) override;
     bool write(QDataStream &out) const override;
-
-    void virtual_hook(int id, void *data) override;
 private:
     QSharedDataPointer<RecoloringSvgIconEnginePrivate> d;
 };
